==> message-service-api-0.0.3-20190627.070440-1-sources.jar: cn/com/duiba/message/service/api/remoteservice/RemoteDingMsgService.java <==
package cn.com.duiba.message.service.api.remoteservice;

import cn.com.duiba.boot.netflix.feign.AdvancedFeignClient;
import cn.com.duiba.message.service.api.dto.DingCardMsgRquest;
import cn.com.duiba.message.service.api.dto.DingIndependenceCardMsgRquest;
import cn.com.duiba.message.service.api.dto.DingGeneralMsgRquest;
import cn.com.duiba.message.service.api.dto.DingMsgSendResult;
import cn.com.duiba.message.service.api.enums.DingMsgTypeEnum;

import java.util.List;

@AdvancedFeignClient
public interface RemoteDingMsgService {

    /**
     * 根据机器人ID发送自定义机器人消息
     *
     * @param robotId     机器人ID
     * @param msgTypeEnum 消息类型
     * @param request     消息体
     * @return
     */
    DingMsgSendResult sendRobotByRobotId(Long robotId, DingMsgTypeEnum msgTypeEnum, DingGeneralMsgRquest request);

    /**
     * 根据机器人token发送自定义机器人消息
     *
     * @param token       机器人ID
     * @param msgTypeEnum 消息类型
     * @param request     消息体
     * @return
     */
    DingMsgSendResult sendRobotByToken(String token, DingMsgTypeEnum msgTypeEnum, DingGeneralMsgRquest request);

    /**
     * 根据机器人token发送自定义机器人消息
     *
     * @param msgTypeEnum 消息类型
     * @param ssoSystemId sso的系统编号
     * @param request     消息体
     * @return
     */
    DingMsgSendResult sendRobotBySystemId(Long ssoSystemId, DingMsgTypeEnum msgTypeEnum, DingGeneralMsgRquest request);

    /**
     * 发送工作通知-全体员工
     *
     * @param request 消息体
     * @return
     */
    DingMsgSendResult sendCorpConversationToAll(DingMsgTypeEnum msgTypeEnum, DingGeneralMsgRquest request);

    /**
     * 发送工作通知
     *
     * @param adminIds 接收消息方
     * @param request  消息体
     * @return
     */
    DingMsgSendResult sendCorpConversation(List<Long> adminIds, DingMsgTypeEnum msgTypeEnum, DingGeneralMsgRquest request);

    /**
     * 发送卡片类型的工作通知
     *
     * @param adminIds  接收消息方
     * @param msgRquest Actioncard样式
     * @return
     */
    DingMsgSendResult sendCardCorpConversation(List<Long> adminIds, DingCardMsgRquest msgRquest);

    /**
     * 发送卡片类型的工作通知- 全体
     *
     * @param msgRquest Actioncard样式
     * @return
     */
    DingMsgSendResult sendCardCorpConversationToAll(DingCardMsgRquest msgRquest);
}

==> message-service-api-0.1.12-sources.jar: cn/com/duiba/message/service/api/remoteservice/RemoteDingMsgService.java <==
package cn.com.duiba.message.service.api.remoteservice;

import cn.com.duiba.boot.netflix.feign.AdvancedFeignClient;
import cn.com.duiba.message.service.api.dto.DingCardMsgRquest;
import cn.com.duiba.message.service.api.dto.DingIndependenceCardMsgRquest;
import cn.com.duiba.message.service.api.dto.DingGeneralMsgRquest;
import cn.com.duiba.message.service.api.dto.DingMsgSendResult;
import cn.com.duiba.message.service.api.enums.DingMsgTypeEnum;

import java.util.List;

@AdvancedFeignClient
public interface RemoteDingMsgService {

    /**
     * 根据机器人ID发送自定义机器人消息
     *
     * @param robotId     机器人ID
     * @param msgTypeEnum 消息类型
     * @param request     消息体
     * @return
     */
    DingMsgSendResult sendRobotByRobotId(Long robotId, DingMsgTypeEnum msgTypeEnum, DingGeneralMsgRquest request);

    /**
     * 根据机器人token发送自定义机器人消息
     *
     * @param token       机器人ID
     * @param msgTypeEnum 消息类型
     * @param request     消息体
     * @return
     */
    DingMsgSendResult sendRobotByToken(String token, DingMsgTypeEnum msgTypeEnum, DingGeneralMsgRquest request);

    /**
     * 根据机器人token发送自定义机器人消息
     *
     * @param msgTypeEnum 消息类型
     * @param appName sso的系统名称
     * @param request     消息体
     * @return
     */
    DingMsgSendResult sendRobotByAppName(String appName, DingMsgTypeEnum msgTypeEnum, DingGeneralMsgRquest request);

    /**
     * 发送工作通知-全体员工
     *
     * @param request 消息体
     * @return
     */
    DingMsgSendResult sendCorpConversationToAll(DingMsgTypeEnum msgTypeEnum, DingGeneralMsgRquest request);

    /**
     * 发送工作通知
     *
     * @param adminIds 接收消息方
     * @param request  消息体
     * @return
     */
    DingMsgSendResult sendCorpConversation(List<Long> adminIds, DingMsgTypeEnum msgTypeEnum, DingGeneralMsgRquest request);

    /**
     * 发送卡片类型的工作通知
     *
     * @param adminIds  接收消息方
     * @param msgRquest Actioncard样式
     * @return
     */
    DingMsgSendResult sendCardCorpConversation(List<Long> adminIds, DingCardMsgRquest msgRquest);

    /**
     * 发送卡片类型的工作通知- 全体
     *
     * @param msgRquest Actioncard样式
     * @return
     */
    DingMsgSendResult sendCardCorpConversationToAll(DingCardMsgRquest msgRquest);
}
